{% include "header.html" %}
  <main class="site-main">
    <h1>{{ page.title }}</h1>
    <p class="taxonomy-desc">Posts tagged with this term:</p>
    {{ content }}
  </main>
{% include "footer.html" %}