<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <meta name="description" content="{{ page.description }}">
  <link rel="icon" href="{{ base_url }}/favicon.ico" type="image/x-icon">
  <title>{{ page.title }} - {{ site.title }}</title>
  {{ og_all_tags }}
  <link rel="stylesheet" href="{{ base_url }}/css/style.css">
  {{ highlight_css }}
  {{ auto_includes_css }}
</head>
<body data-section="{{ page.section }}">