<div class="alert" style="padding: 1rem; border: 1px solid #ddd; background-color: #f9f9f9; border-left: 5px solid #0070f3; margin: 1rem 0;">
  <strong>{{ type | upper }}:</strong> {{ message }}
</div>